@@ -88,14 +88,14 @@ def AnalyzeSpeaker(speaker,form):
     logger.info("Process %s" % str(os.getpid()))
     out = speaker.analyze(form)
     logger.info("Got %s lines for %s" % (str(len(out)),str(speaker)))
-    return speaker.analyze(form)
-    #with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
-    #    f.write("\t".join(out[0].keys()))
-    #    f.write("\n")
-    #    for l in out:
-    #        f.write("\t".join(map(str,l.values())))
-    #        f.write("\n")
-    #logger.info("Completed analysis of %s" % str(speaker))
+    with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
+        f.write("\t".join(out[0].keys()))
+        f.write("\n")
+        for l in out:
+            f.write("\t".join(map(str,l.values())))
+            f.write("\n")
+    logger.info("Completed analysis of %s" % str(speaker))
+    return out
 
 @task()
 def doBasicAnalysis(form):
